@@ -18,7 +18,7 @@ import os.path
 import platform
 import sys
 from ctypes import byref
-
+from .util import SizeLimits
 from pkg_resources import resource_filename
 
 epanet_toolkit = "wntr.epanet.toolkit"
@@ -34,6 +34,7 @@ import logging
 
 logger = logging.getLogger(__name__)
 
+
 # import warnings
 
 
@@ -52,38 +53,37 @@ def ENgetwarning(code, sec=-1):
         header = ""
     if code == 1:
         return (
-            header
-            + "System hydraulically unbalanced - convergence to a hydraulic solution was not achieved in the allowed number of trials"
+                header
+                + "System hydraulically unbalanced - convergence to a hydraulic solution was not achieved in the allowed number of trials"
         )
     elif code == 2:
         return (
-            header
-            + "System may be hydraulically unstable - hydraulic convergence was only achieved after the status of all links was held fixed"
+                header
+                + "System may be hydraulically unstable - hydraulic convergence was only achieved after the status of all links was held fixed"
         )
     elif code == 3:
         return (
-            header
-            + "System disconnected - one or more nodes with positive demands were disconnected for all supply sources"
+                header
+                + "System disconnected - one or more nodes with positive demands were disconnected for all supply sources"
         )
     elif code == 4:
         return (
-            header
-            + "Pumps cannot deliver enough flow or head - one or more pumps were forced to either shut down (due to insufficient head) or operate beyond the maximum rated flow"
+                header
+                + "Pumps cannot deliver enough flow or head - one or more pumps were forced to either shut down (due to insufficient head) or operate beyond the maximum rated flow"
         )
     elif code == 5:
         return (
-            header
-            + "Vavles cannot deliver enough flow - one or more flow control valves could not deliver the required flow even when fully open"
+                header
+                + "Vavles cannot deliver enough flow - one or more flow control valves could not deliver the required flow even when fully open"
         )
     elif code == 6:
         return (
-            header
-            + "System has negative pressures - negative pressures occurred at one or more junctions with positive demand"
+                header
+                + "System has negative pressures - negative pressures occurred at one or more junctions with positive demand"
         )
     else:
         return header + "Unknown warning: %d" % code
 
-
 def runepanet(inpfile, rptfile=None, binfile=None):
     """Run an EPANET command-line simulation
     
@@ -98,7 +98,7 @@ def runepanet(inpfile, rptfile=None, binfile=None):
         rptfile = file_prefix + ".rpt"
     if binfile is None:
         binfile = file_prefix + ".bin"
-    
+
     enData = ENepanet()
     enData.ENopen(inpfile, rptfile, binfile)
     enData.ENsolveH()
@@ -538,6 +538,21 @@ class ENepanet:
         self._error()
         return iCode.value
 
+    def ENgetnodeid(self, iIndex):
+        """
+        desc: Gets the ID name of a node given its index.
+
+        :param a node's index (starting from 1).
+        :return the node's ID name.
+        """
+        fValue = ctypes.create_string_buffer(SizeLimits.EN_MAX_ID.value)
+        if self._project is not None:
+            self.errcode = self.ENlib.EN_getnodeid(self._project, iIndex, byref(fValue))
+        else:
+            self.errcode = self.ENlib.ENgetnodeid(iIndex, byref(fValue))
+        self._error()
+        return str(fValue.value, 'UTF-8')
+
     def ENgetnodeindex(self, sId):
         """Retrieves index of a node with specific ID
 
@@ -559,6 +574,22 @@ class ENepanet:
         self._error()
         return iIndex.value
 
+    def ENgetnodetype(self, iIndex):
+        """
+        desc: Retrieves a node's type given its index.
+
+        :param iIndex: idx
+        :param nodeType: the node's type (see EN_NodeType).
+        :return int node type
+        """
+        fValue = ctypes.c_int()
+        if self._project is not None:
+            self.errcode = self.ENlib.EN_getnodetype(self._project, iIndex, byref(fValue))
+        else:
+            self.errcode = self.ENlib.ENgetnodetype(iIndex, byref(fValue))
+        self._error()
+        return fValue.value
+
     def ENgetnodevalue(self, iIndex, iCode):
         """
         Retrieves parameter value for a node
@@ -605,6 +636,21 @@ class ENepanet:
         self._error()
         return iIndex.value
 
+    def ENgetlinktype(self, iIndex):
+        """
+        Retrieves a link's type.
+
+        :param iIndex: index
+        :return:linkType
+        """
+        fValue = ctypes.c_int()
+        if self._project is not None:
+            self.errcode = self.ENlib.EN_getlinktype(self._project, iIndex, byref(fValue))
+        else:
+            self.errcode = self.ENlib.EN_getlinktype(iIndex, byref(fValue))
+        self._error()
+        return fValue.value
+
     def ENgetlinkvalue(self, iIndex, iCode):
         """Retrieves parameter value for a link
 
@@ -644,8 +690,8 @@ class ENepanet:
         """
         if self._project is not None:
             self.errcode = self.ENlib.EN_setlinkvalue(self._project,
-                ctypes.c_int(iIndex), ctypes.c_int(iCode), ctypes.c_double(fValue)
-            )
+                                                      ctypes.c_int(iIndex), ctypes.c_int(iCode), ctypes.c_double(fValue)
+                                                      )
         else:
             self.errcode = self.ENlib.ENsetlinkvalue(
                 ctypes.c_int(iIndex), ctypes.c_int(iCode), ctypes.c_float(fValue)
@@ -667,8 +713,8 @@ class ENepanet:
         """
         if self._project is not None:
             self.errcode = self.ENlib.EN_setnodevalue(self._project,
-                ctypes.c_int(iIndex), ctypes.c_int(iCode), ctypes.c_double(fValue)
-            )
+                                                      ctypes.c_int(iIndex), ctypes.c_int(iCode), ctypes.c_double(fValue)
+                                                      )
         else:
             self.errcode = self.ENlib.ENsetnodevalue(
                 ctypes.c_int(iIndex), ctypes.c_int(iCode), ctypes.c_float(fValue)
