@@ -48,9 +48,38 @@ __all__ = [
     "MixType",
     "ResultType",
     "EN",
+    "SizeLimits",
+    "InitHydOption"
 ]
 
 
+class SizeLimits(enum.Enum):
+    """
+        Limits on the size of character arrays used to store ID names
+        and text messages.
+    """
+    # // ! < Max.  # characters in ID name
+    EN_MAX_ID = 31
+    # //! < Max.  # characters in message text
+    EN_MAX_MSG = 255
+
+
+class InitHydOption(enum.Enum):
+    """
+        Hydraulic initialization options.
+        These options are used to initialize a new hydraulic analysis
+        when EN_initH is called.
+    """
+    # !< Don't save hydraulics; don't re-initialize flows
+    EN_NOSAVE = 0
+    # !< Save hydraulics to file, don't re-initialize flows
+    EN_SAVE = 1
+    # !< Don't save hydraulics; re-initialize flows
+    EN_INITFLOW = 10
+    # !< Save hydraulics; re-initialize flows
+    EN_SAVE_AND_INIT = 11
+
+
 class FlowUnits(enum.Enum):
     r"""Epanet Units Enum class
 
@@ -328,12 +357,12 @@ class QualParam(enum.Enum):
             mass_units = MassUnits.mg
 
         # Do conversions
-        if self in [QualParam.Concentration, QualParam.Quality, 
+        if self in [QualParam.Concentration, QualParam.Quality,
                     QualParam.LinkQuality, QualParam.ReactionRate]:
             data = data * (mass_units.factor / 0.001)  # MASS /L to kg/m3
             if self in [QualParam.ReactionRate]:
-                data = data / (24*3600)  # 1/day to 1/s
-            
+                data = data / (24 * 3600)  # 1/day to 1/s
+
         elif self in [QualParam.SourceMassInject]:
             data = data * (mass_units.factor / 60.0)  # MASS /min to kg/s
 
@@ -395,12 +424,12 @@ class QualParam(enum.Enum):
             data = np.array(data)
 
         # Do conversions
-        if self in [QualParam.Concentration, QualParam.Quality, 
+        if self in [QualParam.Concentration, QualParam.Quality,
                     QualParam.LinkQuality, QualParam.ReactionRate]:
             data = data / (mass_units.factor / 0.001)  # MASS /L fr kg/m3
             if self in [QualParam.ReactionRate]:
-                data = data * (24*3600)  # 1/day fr 1/s
-                
+                data = data * (24 * 3600)  # 1/day fr 1/s
+
         elif self in [QualParam.SourceMassInject]:
             data = data / (mass_units.factor / 60.0)  # MASS /min fr kg/s
 
@@ -544,8 +573,9 @@ class HydParam(enum.Enum):
             data = data * flow_units.factor
             if self is HydParam.EmitterCoeff:
                 if flow_units.is_traditional:
-                    data = data * np.sqrt(0.7032)  # flowunit/psi0.5 to flowunit/m0.5
-
+                    # flowunit/sqrt(psi) to flowunit/sqrt(m), i.e.,
+                    # flowunit/sqrt(psi) * sqrt(psi/ft / m/ft ) = flowunit/sqrt(m)
+                    data = data * np.sqrt(0.4333 / 0.3048)
         elif self in [HydParam.PipeDiameter]:
             if flow_units.is_traditional:
                 data = data * 0.0254  # in to m
@@ -565,10 +595,10 @@ class HydParam(enum.Enum):
             HydParam.Length]:
             if flow_units.is_traditional:
                 data = data * 0.3048  # ft to m
-        
+
         elif self in [HydParam.HeadLoss]:
             data = data / 1000  # m/1000m or ft/1000ft to unitless
-            
+
         elif self in [HydParam.Velocity]:
             if flow_units.is_traditional:
                 data = data * 0.3048  # ft/s to m/s
@@ -584,8 +614,8 @@ class HydParam(enum.Enum):
 
         elif self in [HydParam.Pressure]:
             if flow_units.is_traditional:
-                #                data = data * 0.703249614902
-                data = data * (0.3048 / 0.4333)  # psi * (m/ft / psi/ft)
+                # psi to m, i.e., psi * (m/ft / psi/ft) = m
+                data = data * (0.3048 / 0.4333)
 
         elif self in [HydParam.Volume]:
             if flow_units.is_traditional:
@@ -636,8 +666,10 @@ class HydParam(enum.Enum):
             data = data / flow_units.factor
             if self is HydParam.EmitterCoeff:
                 if flow_units.is_traditional:
-                    data = data / np.sqrt(0.7032)  # flowunit/psi0.5 from flowunit/m0.5
-
+                    # flowunit/sqrt(psi) from flowunit/sqrt(m), i.e.,
+                    # flowunit/sqrt(m) * sqrt( m/ft / psi/ft ) = flowunit/sqrt(psi), same as
+                    # flowunit/sqrt(m) / sqrt( psi/ft / m/ft ) = flowunit/sqrt(psi)
+                    data = data / np.sqrt(0.4333 / 0.3048)
         elif self in [HydParam.PipeDiameter]:
             if flow_units.is_traditional:
                 data = data / 0.0254  # in from m
@@ -657,10 +689,10 @@ class HydParam(enum.Enum):
             HydParam.Length]:
             if flow_units.is_traditional:
                 data = data / 0.3048  # ft from m
-                    
+
         elif self in [HydParam.HeadLoss]:
             data = data * 1000  # m/1000m or ft/1000ft from unitless
-            
+
         elif self in [HydParam.Velocity]:
             if flow_units.is_traditional:
                 data = data / 0.3048  # ft/s from m/s
@@ -676,10 +708,9 @@ class HydParam(enum.Enum):
 
         elif self in [HydParam.Pressure]:
             if flow_units.is_traditional:
-                #                data = data / 0.703249614902
-                data = data / (
-                    0.3048 / 0.4333
-                )  # psi from mH2O, i.e. psi / (m/ft / psi/ft) )
+                # psi from m, i.e., m * (psi/ft / m/ft) = psi, same as
+                # m / ( m/ft / psi/m ) = psi
+                data = data / (0.3048 / 0.4333)
 
         elif self in [HydParam.Volume]:
             if flow_units.is_traditional:
@@ -1187,13 +1218,13 @@ class EN(enum.IntEnum):
 
 
 def to_si(
-    from_units: FlowUnits,
-    data,
-    param,
-    mass_units: MassUnits = MassUnits.mg,
-    pressure_units: PressureUnits = None,
-    darcy_weisbach: bool = False,
-    reaction_order: int = 0,
+        from_units: FlowUnits,
+        data,
+        param,
+        mass_units: MassUnits = MassUnits.mg,
+        pressure_units: PressureUnits = None,
+        darcy_weisbach: bool = False,
+        reaction_order: int = 0,
 ):
     """Convert an EPANET parameter from internal to SI standard units.
 
@@ -1275,13 +1306,13 @@ def to_si(
 
 
 def from_si(
-    to_units: FlowUnits,
-    data,
-    param,
-    mass_units: MassUnits = MassUnits.mg,
-    pressure_units: PressureUnits = None,
-    darcy_weisbach: bool = False,
-    reaction_order: int = 0,
+        to_units: FlowUnits,
+        data,
+        param,
+        mass_units: MassUnits = MassUnits.mg,
+        pressure_units: PressureUnits = None,
+        darcy_weisbach: bool = False,
+        reaction_order: int = 0,
 ):
     """Convert an EPANET parameter from SI standard units back to internal units.
 
